@@ -254,7 +254,7 @@
 
         html += '<td data-title="Date">';
         var date = datetime.parseISO8601Date(item.Date, true);
-        html += date.toLocaleDateString();
+        html += datetime.toLocaleDateString(date);
         html += '</td>';
 
         html += '<td data-title="Source" class="fileCell">';
