@@ -1,7 +1,8 @@
-﻿define(['libraryBrowser', 'cardBuilder', 'apphost', 'scrollStyles', 'emby-itemscontainer', 'emby-tabs', 'emby-button'], function (libraryBrowser, cardBuilder, appHost) {
+﻿define(['libraryBrowser', 'cardBuilder', 'apphost', 'imageLoader', 'scrollStyles', 'emby-itemscontainer', 'emby-tabs', 'emby-button'], function (libraryBrowser, cardBuilder, appHost, imageLoader) {
+    'use strict';
 
     function enableScrollX() {
-        return browserInfo.mobile && AppInfo.enableAppLayouts;
+        return browserInfo.mobile;
     }
 
     function renderRecordings(elem, recordings, cardOptions) {
@@ -36,7 +37,7 @@
 
         }, cardOptions || {}));
 
-        ImageLoader.lazyChildren(recordingItems);
+        imageLoader.lazyChildren(recordingItems);
     }
 
     function getBackdropShape() {
@@ -98,14 +99,15 @@
 
         }).then(function (result) {
 
-            renderItems(page, result.Items, 'activeProgramItems', 'play');
+            renderItems(page, result.Items, 'activeProgramItems', 'play', {
+                showAirDateTime: false,
+                showAirEndTime: true
+            });
             Dashboard.hideLoadingMsg();
         });
     }
 
-    function reload(page) {
-
-        loadRecommendedPrograms(page);
+    function reload(page, enableFullRender) {
 
         renderActiveRecordings(page, ApiClient.getLiveTvRecordings({
             UserId: Dashboard.getCurrentUserId(),
@@ -115,6 +117,12 @@
             EnableImageTypes: "Primary,Thumb,Backdrop"
         }));
 
+        if (!enableFullRender) {
+            return;
+        }
+
+        loadRecommendedPrograms(page);
+
         ApiClient.getLiveTvRecommendedPrograms({
 
             userId: Dashboard.getCurrentUserId(),
@@ -147,7 +155,10 @@
 
         }).then(function (result) {
 
-            renderItems(page, result.Items, 'upcomingTvMovieItems', null, getPortraitShape());
+            renderItems(page, result.Items, 'upcomingTvMovieItems', null, {
+                shape: getPortraitShape(),
+                preferThumb: null
+            });
         });
 
         ApiClient.getLiveTvRecommendedPrograms({
@@ -183,15 +194,17 @@
         });
     }
 
-    function renderItems(page, items, sectionClass, overlayButton, shape) {
+    function renderItems(page, items, sectionClass, overlayButton, cardOptions) {
 
         var supportsImageAnalysis = appHost.supports('imageanalysis');
 
-        var html = cardBuilder.getCardsHtml({
+        cardOptions = cardOptions || {};
+
+        var html = cardBuilder.getCardsHtml(Object.assign({
             items: items,
-            preferThumb: !shape,
+            preferThumb: true,
             inheritThumb: false,
-            shape: shape || (enableScrollX() ? 'overflowBackdrop' : 'backdrop'),
+            shape: (enableScrollX() ? 'overflowBackdrop' : 'backdrop'),
             showParentTitleOrTitle: true,
             showTitle: false,
             centerText: !supportsImageAnalysis,
@@ -206,17 +219,22 @@
             showChannelName: true,
             vibrant: true,
             cardLayout: supportsImageAnalysis
-        });
+
+        }, cardOptions));
 
         var elem = page.querySelector('.' + sectionClass);
 
         elem.innerHTML = html;
-        ImageLoader.lazyChildren(elem);
+        imageLoader.lazyChildren(elem);
     }
 
     return function (view, params) {
 
         var self = this;
+        var lastFullRender = 0;
+        function enableFullRender() {
+            return (new Date().getTime() - lastFullRender) > 300000;
+        }
 
         self.initTab = function () {
 
@@ -237,11 +255,18 @@
 
         self.renderTab = function () {
             var tabContent = view.querySelector('.pageTabContent[data-index=\'' + 0 + '\']');
-            reload(tabContent);
+
+            if (enableFullRender()) {
+                reload(tabContent, true);
+                lastFullRender = new Date().getTime();
+            } else {
+                reload(tabContent);
+            }
         };
 
         var tabControllers = [];
         var renderedTabs = [];
+        var currentTabController;
 
         function getTabController(page, index, callback) {
 
@@ -319,7 +344,12 @@
                         renderedTabs.push(index);
                     }
                     controller.renderTab();
+                } else {
+                    if (controller.onShow) {
+                        controller.onShow();
+                    }
                 }
+                currentTabController = controller;
             });
         }
 
@@ -332,11 +362,20 @@
         });
 
         viewTabs.addEventListener('tabchange', function (e) {
+
+            var previousTabController = tabControllers[parseInt(e.detail.previousIndex)];
+            if (previousTabController && previousTabController.onHide) {
+                previousTabController.onHide();
+            }
+
             loadTab(view, parseInt(e.detail.selectedTabIndex));
         });
 
         view.addEventListener('viewbeforehide', function (e) {
 
+            if (currentTabController && currentTabController.onHide) {
+                currentTabController.onHide();
+            }
             document.body.classList.remove('autoScrollY');
         });
 
