@@ -1,14 +1,15 @@
-﻿define(['libraryBrowser', 'cardBuilder', 'scrollStyles', 'emby-itemscontainer'], function (libraryBrowser, cardBuilder) {
+﻿define(['libraryBrowser', 'cardBuilder', 'dom', 'apphost', 'imageLoader', 'libraryMenu', 'scrollStyles', 'emby-itemscontainer', 'emby-tabs', 'emby-button'], function (libraryBrowser, cardBuilder, dom, appHost, imageLoader, libraryMenu) {
+    'use strict';
 
     function itemsPerRow() {
 
-        var screenWidth = window.innerWidth;
+        var screenWidth = dom.getWindowSize().innerWidth;
 
         return screenWidth >= 1920 ? 9 : (screenWidth >= 1200 ? 12 : (screenWidth >= 1000 ? 10 : 8));
     }
 
     function enableScrollX() {
-        return browserInfo.mobile && AppInfo.enableAppLayouts;
+        return browserInfo.mobile;
     }
 
     function getSquareShape() {
@@ -24,7 +25,7 @@
         var options = {
             IncludeItemTypes: "Audio",
             Limit: itemsPerRow(),
-            Fields: "PrimaryImageAspectRatio,SyncInfo",
+            Fields: "PrimaryImageAspectRatio,BasicSyncInfo",
             ParentId: parentId,
             ImageTypeLimit: 1,
             EnableImageTypes: "Primary,Backdrop,Banner,Thumb",
@@ -34,6 +35,9 @@
         ApiClient.getJSON(ApiClient.getUrl('Users/' + userId + '/Items/Latest', options)).then(function (items) {
 
             var elem = page.querySelector('#recentlyAddedSongs');
+
+            var supportsImageAnalysis = appHost.supports('imageanalysis');
+
             elem.innerHTML = cardBuilder.getCardsHtml({
                 items: items,
                 showUnplayedIndicator: false,
@@ -42,11 +46,14 @@
                 showTitle: true,
                 showParentTitle: true,
                 lazy: true,
-                centerText: true,
-                overlayPlayButton: true
+                centerText: !supportsImageAnalysis,
+                overlayPlayButton: !supportsImageAnalysis,
+                allowBottomPadding: !enableScrollX(),
+                cardLayout: supportsImageAnalysis,
+                vibrant: supportsImageAnalysis
 
             });
-            ImageLoader.lazyChildren(elem);
+            imageLoader.lazyChildren(elem);
 
             Dashboard.hideLoadingMsg();
         });
@@ -80,6 +87,9 @@
             }
 
             var itemsContainer = elem.querySelector('.itemsContainer');
+
+            var supportsImageAnalysis = appHost.supports('imageanalysis');
+
             itemsContainer.innerHTML = cardBuilder.getCardsHtml({
                 items: result.Items,
                 showUnplayedIndicator: false,
@@ -88,11 +98,14 @@
                 showParentTitle: true,
                 action: 'instantmix',
                 lazy: true,
-                centerText: true,
-                overlayMoreButton: true
+                centerText: !supportsImageAnalysis,
+                overlayMoreButton: !supportsImageAnalysis,
+                allowBottomPadding: !enableScrollX(),
+                cardLayout: supportsImageAnalysis,
+                vibrant: supportsImageAnalysis
 
             });
-            ImageLoader.lazyChildren(itemsContainer);
+            imageLoader.lazyChildren(itemsContainer);
 
         });
 
@@ -126,6 +139,9 @@
             }
 
             var itemsContainer = elem.querySelector('.itemsContainer');
+
+            var supportsImageAnalysis = appHost.supports('imageanalysis');
+
             itemsContainer.innerHTML = cardBuilder.getCardsHtml({
                 items: result.Items,
                 showUnplayedIndicator: false,
@@ -134,11 +150,14 @@
                 showParentTitle: true,
                 action: 'instantmix',
                 lazy: true,
-                centerText: true,
-                overlayMoreButton: true
+                centerText: !supportsImageAnalysis,
+                overlayMoreButton: !supportsImageAnalysis,
+                allowBottomPadding: !enableScrollX(),
+                cardLayout: supportsImageAnalysis,
+                vibrant: supportsImageAnalysis
 
             });
-            ImageLoader.lazyChildren(itemsContainer);
+            imageLoader.lazyChildren(itemsContainer);
 
         });
 
@@ -169,6 +188,9 @@
             }
 
             var itemsContainer = elem.querySelector('.itemsContainer');
+
+            var supportsImageAnalysis = appHost.supports('imageanalysis');
+
             itemsContainer.innerHTML = cardBuilder.getCardsHtml({
                 items: result.Items,
                 shape: getSquareShape(),
@@ -176,18 +198,19 @@
                 lazy: true,
                 coverImage: true,
                 showItemCounts: true,
-                centerText: true,
-                overlayPlayButton: true
+                centerText: !supportsImageAnalysis,
+                overlayPlayButton: !supportsImageAnalysis,
+                allowBottomPadding: !enableScrollX(),
+                cardLayout: supportsImageAnalysis,
+                vibrant: supportsImageAnalysis
 
             });
-            ImageLoader.lazyChildren(itemsContainer);
+            imageLoader.lazyChildren(itemsContainer);
 
         });
     }
 
-    function loadSuggestionsTab(page, tabContent) {
-
-        var parentId = LibraryMenu.getTopParentId();
+    function loadSuggestionsTab(page, tabContent, parentId) {
 
         console.log('loadSuggestionsTab');
         loadLatest(tabContent, parentId);
@@ -202,31 +225,6 @@
         });
     }
 
-    pageIdOn('pagebeforeshow', "musicRecommendedPage", function () {
-
-        var page = this;
-
-        if (!page.getAttribute('data-title')) {
-
-            var parentId = LibraryMenu.getTopParentId();
-
-            if (parentId) {
-
-                ApiClient.getItem(Dashboard.getCurrentUserId(), parentId).then(function (item) {
-
-                    page.setAttribute('data-title', item.Name);
-                    LibraryMenu.setTitle(item.Name);
-                });
-
-
-            } else {
-                page.setAttribute('data-title', Globalize.translate('TabMusic'));
-                LibraryMenu.setTitle(Globalize.translate('TabMusic'));
-            }
-        }
-
-    });
-
     return function (view, params) {
 
         var self = this;
@@ -236,15 +234,11 @@
             Dashboard.showLoadingMsg();
 
             var tabContent = view.querySelector('.pageTabContent[data-index=\'' + 0 + '\']');
-            loadSuggestionsTab(view, tabContent);
+            loadSuggestionsTab(view, tabContent, params.topParentId);
         }
 
         function enableScrollX() {
-            return browserInfo.mobile && AppInfo.enableAppLayouts;
-        }
-
-        function getThumbShape() {
-            return enableScrollX() ? 'overflowBackdrop' : 'backdrop';
+            return browserInfo.mobile;
         }
 
         self.initTab = function () {
@@ -349,25 +343,49 @@
             });
         }
 
-        var mdlTabs = view.querySelector('.libraryViewNav');
+        var viewTabs = view.querySelector('.libraryViewNav');
 
-        var baseUrl = 'music.html';
-        var topParentId = params.topParentId;
-        if (topParentId) {
-            baseUrl += '?topParentId=' + topParentId;
-        }
+        libraryBrowser.configurePaperLibraryTabs(view, viewTabs, view.querySelectorAll('.pageTabContent'), [0, 4, 5, 6]);
 
-        libraryBrowser.configurePaperLibraryTabs(view, mdlTabs, view.querySelectorAll('.pageTabContent'), [0, 4, 5, 6]);
-
-        mdlTabs.addEventListener('beforetabchange', function (e) {
+        viewTabs.addEventListener('beforetabchange', function (e) {
             preLoadTab(view, parseInt(e.detail.selectedTabIndex));
         });
-        mdlTabs.addEventListener('tabchange', function (e) {
+        viewTabs.addEventListener('tabchange', function (e) {
             loadTab(view, parseInt(e.detail.selectedTabIndex));
         });
 
+        view.addEventListener('viewbeforeshow', function (e) {
+
+            if (!view.getAttribute('data-title')) {
+
+                var parentId = params.topParentId;
+
+                if (parentId) {
+
+                    ApiClient.getItem(Dashboard.getCurrentUserId(), parentId).then(function (item) {
+
+                        view.setAttribute('data-title', item.Name);
+                        libraryMenu.setTitle(item.Name);
+                    });
+
+
+                } else {
+                    view.setAttribute('data-title', Globalize.translate('TabMusic'));
+                    libraryMenu.setTitle(Globalize.translate('TabMusic'));
+                }
+            }
+        });
+
+        require(["headroom-window"], function (headroom) {
+            headroom.add(viewTabs);
+            self.headroom = headroom;
+        });
+
         view.addEventListener('viewdestroy', function (e) {
 
+            if (self.headroom) {
+                self.headroom.remove(viewTabs);
+            }
             tabControllers.forEach(function (t) {
                 if (t.destroy) {
                     t.destroy();
